@@ -6,7 +6,7 @@
 #' @inheritParams simulatePedigree
 #' @inheritParams createGenDataFrame
 #' @return A data frame representing the simulated pedigree, including columns for family ID (`fam`),
-buildWithinGenerations <- function(sizeGens, marR, sexR, Ngen) {
+buildWithinGenerations <- function(sizeGens, marR, sexR, Ngen, verbose = FALSE) {
   for (i in 1:Ngen) {
     idGen <- as.numeric(paste(100, i, 1:sizeGens[i], sep = ""))
     # idGen <- ifelse(i==1,
@@ -24,8 +24,7 @@ buildWithinGenerations <- function(sizeGens, marR, sexR, Ngen) {
 
     df_Ngen$sex <- determineSex(idGen = idGen, sexR = sexR)
 
-
-    # print(paste("tiger",i))
+    # message(paste("tiger",i))
     # The first generation
     if (i == 1) {
       df_Ngen$spID[1] <- df_Ngen$id[2]
@@ -56,9 +55,9 @@ buildWithinGenerations <- function(sizeGens, marR, sexR, Ngen) {
 
       # sample single ids from male ids and female ids
       usedFemaleIds <- sample(df_Ngen$id[df_Ngen$sex == "F"], nSingleFemale)
-      ## print(c("Used F", usedFemaleIds))
+      ## message(c("Used F", usedFemaleIds))
       usedMaleIds <- sample(df_Ngen$id[df_Ngen$sex == "M"], nSingleMale)
-      ## print(c("Used M", usedMaleIds))
+      ## message(c("Used M", usedMaleIds))
 
       usedIds <- c(usedFemaleIds, usedMaleIds)
 
@@ -98,7 +97,7 @@ buildWithinGenerations <- function(sizeGens, marR, sexR, Ngen) {
             }
           }
         }
-        # print(usedIds)
+        # message(usedIds)
       }
     }
     if (i == 1) {
@@ -135,7 +134,7 @@ buildWithinGenerations <- function(sizeGens, marR, sexR, Ngen) {
 #'         as well as assigning unique couple IDs. It does not return a value explicitly.
 #'
 
-buildBetweenGenerations <- function(df_Fam, Ngen, sizeGens, verbose, marR, sexR, kpc, rd_kpc) {
+buildBetweenGenerations <- function(df_Fam, Ngen, sizeGens, verbose = FALSE, marR, sexR, kpc, rd_kpc) {
   df_Fam$ifparent <- FALSE
   df_Fam$ifson <- FALSE
   df_Fam$ifdau <- FALSE
@@ -172,7 +171,7 @@ buildBetweenGenerations <- function(df_Fam, Ngen, sizeGens, verbose, marR, sexR,
       # Start to connect children with mother and father
       #
       if (verbose) {
-        print(
+        message(
           "Step 2.1: mark a group of potential sons and daughters in the i th generation"
         )
       }
@@ -181,11 +180,9 @@ buildBetweenGenerations <- function(df_Fam, Ngen, sizeGens, verbose, marR, sexR,
       # count the number of couples in the i th gen
       countCouple <- (nrow(df_Ngen) - sum(is.na(df_Ngen$spID))) * .5
 
-
       # Now, assign couple IDs for the current generation
       df_Ngen <- assignCoupleIds(df_Ngen)
 
-
       # get the number of linked female and male children after excluding the single children
       # get a vector of single person id in the ith generation
       IdSingle <- df_Ngen$id[is.na(df_Ngen$spID)]
@@ -194,11 +191,15 @@ buildBetweenGenerations <- function(df_Fam, Ngen, sizeGens, verbose, marR, sexR,
       SingleM <- sum(df_Ngen$sex == "M" & is.na(df_Ngen$spID))
       CoupleM <- N_LinkedMale - SingleM
 
-      df_Fam[df_Fam$gen == i, ] <- markPotentialChildren(df_Ngen = df_Ngen, i = i, Ngen = Ngen, sizeGens = sizeGens, CoupleF = CoupleF)
-
-
+      df_Fam[df_Fam$gen == i, ] <- markPotentialChildren(
+        df_Ngen = df_Ngen,
+        i = i,
+        Ngen = Ngen,
+        sizeGens = sizeGens,
+        CoupleF = CoupleF
+      )
       if (verbose) {
-        print(
+        message(
           "Step 2.2: mark a group of potential parents in the i-1 th generation"
         )
       }
@@ -229,7 +230,7 @@ buildBetweenGenerations <- function(df_Fam, Ngen, sizeGens, verbose, marR, sexR,
       df_Ngen <- df_Ngen[order(as.numeric(rownames(df_Ngen))), , drop = FALSE]
       df_Fam[df_Fam$gen == i - 1, ] <- df_Ngen
       if (verbose) {
-        print(
+        message(
           "Step 2.3: connect the i and i-1 th generation"
         )
       }
@@ -241,17 +242,16 @@ buildBetweenGenerations <- function(df_Fam, Ngen, sizeGens, verbose, marR, sexR,
         sizeI <- sizeGens[i - 1]
         sizeII <- sizeGens[i]
         # create a vector with ordered ids that should be connected to a parent
-        # print(df_Ngen)
+        # message(df_Ngen)
         IdSon <- df_Ngen$id[df_Ngen$ifson == TRUE & df_Ngen$gen == i]
-        # print(IdSon)
+        # message(IdSon)
         IdDau <- df_Ngen$id[df_Ngen$ifdau == TRUE & df_Ngen$gen == i]
-        # print(IdDau)
+        # message(IdDau)
         IdOfp <- evenInsert(IdSon, IdDau)
 
         # generate link kids to the couples
         random_numbers <- adjustKidsPerCouple(nMates = sum(df_Ngen$ifparent) / 2, kpc = kpc, rd_kpc = rd_kpc)
 
-
         # cat("final random numbers",random_numbers, "\n")
         # cat("mean",sum(random_numbers)/length(random_numbers), "\n")
         # create two vectors for maId and paId; replicate the ids to match the same length as IdOfp
@@ -286,7 +286,7 @@ buildBetweenGenerations <- function(df_Fam, Ngen, sizeGens, verbose, marR, sexR,
         ### making sure sampling out the single people instead of couples
         if (length(IdPa) - length(IdOfp) > 0) {
           if (verbose) {
-            print("length of IdPa", length(IdPa), "\n")
+            message("length of IdPa", length(IdPa), "\n")
           }
           IdRm <- sample.int(length(IdPa), size = length(IdPa) - length(IdOfp))
           IdPa <- IdPa[-IdRm]
@@ -307,17 +307,17 @@ buildBetweenGenerations <- function(df_Fam, Ngen, sizeGens, verbose, marR, sexR,
         #       IdRm <- sample.int(length(IdOfp),size =length(IdOfp)-length(IdMa))
         #       IdOfp <- IdOfp[-IdRm]
         # }
-        # print(matrix(c(IdPa, IdMa), ncol = 2))
+        # message(matrix(c(IdPa, IdMa), ncol = 2))
 
-        # print(IdPa)
-        # print(IdOfp)
+        # message(IdPa)
+        # message(IdOfp)
 
         # put the IdMa and IdPa into the dfFam with correspondent OfpId
         for (m in seq_along(IdOfp)) {
           df_Ngen[df_Ngen$id == IdOfp[m], "pat"] <- IdPa[m]
           df_Ngen[df_Ngen$id == IdOfp[m], "mat"] <- IdMa[m]
         }
-        # print(df_Ngen)
+        # message(df_Ngen)
         df_Fam[df_Fam$gen == i, ] <- df_Ngen[df_Ngen$gen == i, ]
         df_Fam[df_Fam$gen == i - 1, ] <- df_Ngen[df_Ngen$gen == i - 1, ]
       }
@@ -342,7 +342,8 @@ buildBetweenGenerations <- function(df_Fam, Ngen, sizeGens, verbose, marR, sexR,
 #' @param rd_kpc logical. If TRUE, the number of kids per mate will be randomly generated from a poisson distribution with mean kpc. If FALSE, the number of kids per mate will be fixed at kpc.
 #' @param balancedSex Not fully developed yet. Always \code{TRUE} in the current version.
 #' @param balancedMar Not fully developed yet. Always \code{TRUE} in the current version.
-#' @param verbose logical  If TRUE, print progress through stages of algorithm
+#' @param verbose logical  If TRUE, message progress through stages of algorithm
+#' @param ... Additional arguments to be passed to other functions.
 
 #' @return A \code{data.frame} with each row representing a simulated individual. The columns are as follows:
 #' \itemize{
@@ -371,29 +372,37 @@ simulatePedigree <- function(kpc = 3,
   sizeGens <- allGens(kpc = kpc, Ngen = Ngen, marR = marR)
   #  famSizeIndex <- 1:sum(sizeGens)
   if (verbose) {
-    print(
+    message(
       "Step 1: Let's build the connection within each generation first"
     )
   }
   df_Fam <- buildWithinGenerations(
     sizeGens = sizeGens,
-    Ngen = Ngen, sexR = sexR, marR = marR
+    Ngen = Ngen,
+    sexR = sexR,
+    marR = marR,
+    verbose = verbose
   )
   if (verbose) {
-    print(
+    message(
       "Step 2: Let's try to build connection between each two generations"
     )
   }
 
   df_Fam <- buildBetweenGenerations(
-    df_Fam = df_Fam, Ngen = Ngen,
-    sizeGens = sizeGens, verbose = verbose, marR = marR, sexR = sexR, kpc = kpc, rd_kpc = rd_kpc
+    df_Fam = df_Fam,
+    Ngen = Ngen,
+    sizeGens = sizeGens,
+    verbose = verbose,
+    marR = marR,
+    sexR = sexR,
+    kpc = kpc,
+    rd_kpc = rd_kpc
   )
 
-
-
   df_Fam <- df_Fam[, 1:7]
   df_Fam <- df_Fam[!(is.na(df_Fam$pat) & is.na(df_Fam$mat) & is.na(df_Fam$spID)), ]
+
   colnames(df_Fam)[c(2, 4, 5)] <- c("ID", "dadID", "momID")
 
   # connect the detached members
@@ -405,6 +414,13 @@ simulatePedigree <- function(kpc = 3,
   #    df_Fam$sex[df_Fam$sex == "F"] <- "M"
   #    df_Fam$sex[df_Fam$sex == "F1"] <- "F"
   #  }
-  # print(df_Fam)
+  # message(df_Fam)
   return(df_Fam)
 }
+
+#' @rdname simulatePedigree
+#' @export
+SimPed <- function(...) { # nolint: object_name_linter.
+  warning("The 'SimPed' function is deprecated. Please use 'simulatePedigree' instead.")
+  simulatePedigree(...)
+}
